==> icons-vue-0.6.0.tgz: package/lib/flow--stream/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_FlowStream16 = {
  name: 'FlowStream16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M20,24H11.86a4.17,4.17,0,0,0-.43-1L22,12.43A3.86,3.86,0,0,0,24,13a4,4,0,1,0-3.86-5H14v2h6.14a4.17,4.17,0,0,0,.43,1L10,21.57A3.86,3.86,0,0,0,8,21a4,4,0,1,0,3.86,5H20v3h8V21H20ZM24,7a2,2,0,1,1-2,2A2,2,0,0,1,24,7ZM8,27a2,2,0,1,1,2-2A2,2,0,0,1,8,27Zm14-4h4v4H22Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M7.05,15.75a9,9,0,0,1,0-13.5l1.32,1.5a7,7,0,0,0,0,10.5Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M9.69,12.75a5,5,0,0,1,0-7.5L11,6.75a3,3,0,0,0,0,4.5Z"
      }
    }), children]);
  }
};

module.exports = virtual_FlowStream16;

==> icons-vue-10.6.1.tgz: package/lib/flow--stream/16.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@carbon/icon-helpers');

var virtual_FlowStream16 = {
  name: 'FlowStream16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M20 24h-8.14a4.17 4.17 0 0 0-.43-1L22 12.43a3.86 3.86 0 0 0 2 .57 4 4 0 1 0-3.86-5H14v2h6.14a4.17 4.17 0 0 0 .43 1L10 21.57A3.86 3.86 0 0 0 8 21a4 4 0 1 0 3.86 5H20v3h8v-8h-8zm4-17a2 2 0 1 1-2 2 2 2 0 0 1 2-2zM8 27a2 2 0 1 1 2-2 2 2 0 0 1-2 2zm14-4h4v4h-4zM7.05 15.75a9 9 0 0 1 0-13.5l1.32 1.5a7 7 0 0 0 0 10.5z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M9.69 12.75a5 5 0 0 1 0-7.5L11 6.75a3 3 0 0 0 0 4.5z"
      }
    }), children]);
  }
};

module.exports = virtual_FlowStream16;
